@@ -9,7 +9,7 @@ try:
 except ImportError:
     sys.path.append(
         os.path.join(
-            os.path.dirname(os.path.dirname(os.path.realpath(__file__))), "lib"
+            os.path.dirname(os.path.dirname(os.path.realpath(__file__))), "lib/python"
         )
     )
     import jpipe.jpp.main
@@ -19,6 +19,7 @@ class JPPTest(unittest.TestCase):
     def testJPP(self):
         for input_args, input_json, input_expr, expected_output, expected_retval in (
             ((), """{"hello": "world"}""", "@", '{\n  "hello": "world"\n}\n', 0),
+            (("-c",), "{}", "@", "{}\n", 0),
             (("-c",), """{"hello": "world"}""", "@", '{"hello":"world"}\n', 0),
             (
                 ("-c",),
